@@ -10,23 +10,14 @@ class MixNet(nn.Module):
         self.subnet_b = qnet_type(input_size_b, hidden_size, output_size)
 
         self.linear_i2h = nn.Linear(input_size_a + input_size_b, hidden_size)
-        self.linear_h2w = nn.Linear(hidden_size, 2)
+        self.linear_h2w = nn.Linear(hidden_size, 1)
 
     def forward(self, x_a, x_b):
-        y_a = self.subnet_a(x_a)
-        y_b = self.subnet_b(x_b)
+        w = F.tanh(self.linear_i2h(torch.cat([x_a, x_b], dim=-1)))
+        w = F.sigmoid(self.linear_h2w(w))
 
-        x_w = F.tanh(self.linear_i2h(torch.cat([x_a, x_b], dim=-1)))
-        x_w = F.sigmoid(self.linear_h2w(x_w))
-
-        # x_a => batch_size * output_size
-        # x_b => batch_size * output_size
-        # x_w => batch_size * 2
-        x_w_a, x_w_b = x_w.split(1, dim=-1)
-        x_w_a = x_w_a.expand(dim=-1)
-        y_a = torch.mm(y_a, x_w_a)
-        x_w_b = x_w_b.expand(dim=-1)
-        y_b = torch.mm(y_b, x_w_b)
+        y_a = self.subnet_a(x_a) * w
+        y_b = self.subnet_b(x_b) * (1 - w)
 
         return y_a + y_b
 
